@@ -28,14 +28,14 @@ from couchdbkit.client import Database
 from couchdbkit.schema import properties as p
 from couchdbkit.schema.properties import value_to_python, \
 convert_property, MAP_TYPES_PROPERTIES, ALLOWED_PROPERTY_TYPES, \
-LazyDict, LazyList
+LazyDict, LazyList, value_to_json
 from couchdbkit.exceptions import *
 from couchdbkit.resource import ResourceNotFound
 
 
 __all__ = ['ReservedWordError', 'ALLOWED_PROPERTY_TYPES', 'DocumentSchema', 
         'SchemaProperties', 'DocumentBase', 'QueryMixin', 'AttachmentMixin', 
-        'Document', 'StaticDocument']
+        'Document', 'StaticDocument', 'valid_id']
 
 _RESERVED_WORDS = ['_id', '_rev', '$schema', 'type']
 
@@ -108,14 +108,14 @@ class DocumentSchema(object):
     _doc = None
     _db = None
     
-    def __init__(self, d=None, **properties):
+    def __init__(self, _d=None, **properties):
         self._dynamic_properties = {} 
         self._doc = {}
 
-        if d is not None:
-            if not isinstance(d, dict):
+        if _d is not None:
+            if not isinstance(_d, dict):
                 raise TypeError('d should be a dict')
-            properties.update(d)
+            properties.update(_d)
             
         doc_type = getattr(self, '_doc_type', self.__class__.__name__)
         self._doc['doc_type'] = doc_type
@@ -200,13 +200,14 @@ class DocumentSchema(object):
                     self._dynamic_properties = {}
                 
                 if isinstance(value, dict):
-                    if key not in self._doc:
+                    if key not in self._doc or not value:
                         self._doc[key] = {}
                     value = LazyDict(value, self._doc[key])
                 elif isinstance(value, list):
-                    if key not in self._doc:
+                    if key not in self._doc or not value:
                         self._doc[key] = []
                     value = LazyList(value, self._doc[key])
+                    
                 self._dynamic_properties[key] = value
 
                 if not isinstance(value, (p.Property,)) and \
@@ -242,7 +243,10 @@ class DocumentSchema(object):
         """ get property value
         """
         try:
-            return getattr(self, key)
+            attr = getattr(self, key)
+            if callable(attr):
+                raise AttributeError
+            return attr
         except AttributeError, e:
             if key in self._doc:
                 return self._doc[key]
@@ -402,11 +406,11 @@ class DocumentBase(DocumentSchema):
     """
     _db = None
 
-    def __init__(self, d=None, **kwargs):
+    def __init__(self, _d=None, **kwargs):
         docid = None
         if '_id' in kwargs:
             docid = kwargs.pop('_id')
-        DocumentSchema.__init__(self, d, **kwargs)
+        DocumentSchema.__init__(self, _d, **kwargs)
         if docid is not None:
             self._doc['_id'] = valid_id(docid)
 
@@ -423,7 +427,7 @@ class DocumentBase(DocumentSchema):
             raise TypeError("doc database required to save document")
         return db
     
-    def save(self):
+    def save(self, **params):
         """ Save document in database.
             
         @params db: couchdbkit.core.Database instance
@@ -433,23 +437,32 @@ class DocumentBase(DocumentSchema):
             raise TypeError("doc database required to save document")
         
         doc = self.to_json()
-        self._db.save_doc(doc)
-        self._doc.update({'_id': doc['_id'], '_rev': doc['_rev']})
+        self._db.save_doc(doc, **params)
+        if '_id' in doc and '_rev' in doc:
+            self._doc.update({'_id': doc['_id'], '_rev': doc['_rev']})
+        elif '_id' in doc:
+            self._doc.update({'_id': doc['_id']})
         
     store = save
 
     @classmethod
-    def bulk_save(cls, docs):
+    def bulk_save(cls, docs, use_uuids=True, all_or_nothing=False):
         """ Save multiple documents in database.
             
         @params docs: list of couchdbkit.schema.Document instance
+        @param use_uuids: add _id in doc who don't have it already set.
+        @param all_or_nothing: In the case of a power failure, when the database 
+        restarts either all the changes will have been saved or none of them. 
+        However, it does not do conflict checking, so the documents will 
+        be committed even if this creates conflicts.
+        
         """
         if cls._db is None:
             raise TypeError("doc database required to save document")
         docs_to_save= [doc._doc for doc in docs if doc._doc_type == cls._doc_type]
         if not len(docs_to_save) == len(docs):
             raise ValueError("one of your documents does not have the correct type")
-        cls._db.bulk_save(docs_to_save)
+        cls._db.bulk_save(docs_to_save, use_uuids=use_uuids, all_or_nothing=all_or_nothing)
     
     @classmethod
     def get(cls, docid, rev=None, db=None, dynamic_properties=True):
@@ -463,7 +476,7 @@ class DocumentBase(DocumentSchema):
         return cls._db.get(docid, rev=rev, wrapper=cls.wrap)
         
     @classmethod
-    def get_or_create(cls, docid=None, db=None, dynamic_properties=True):
+    def get_or_create(cls, docid=None, db=None, dynamic_properties=True, **params):
         """ get  or create document with `docid` """
         if db is not None:
             cls._db = db
@@ -475,18 +488,36 @@ class DocumentBase(DocumentSchema):
             
         if docid is None:
             obj = cls()
-            obj.save()
+            obj.save(**params)
             return obj
         
+        rev = params.pop('rev', None)
+        
         try:
-            return cls._db.get(docid, wrapper=cls.wrap)
+            return cls._db.get(docid, rev=rev, wrapper=cls.wrap, **params)
         except ResourceNotFound:
             obj = cls()
-            obj.id = docid
-            obj.save()
+            obj._id = docid
+            obj.save(**params)
             return obj
   
-    new_document = property(lambda self: self._doc.get('_rev') is None) 
+    new_document = property(lambda self: self._doc.get('_rev') is None)
+    
+    def delete(self):
+        """ Delete document from the database.
+        @params db: couchdbkit.core.Database instance
+        """
+        if self._db is None:
+            raise TypeError("doc database required to save document")
+    
+        if self.new_document:
+            raise TypeError("the document is not saved")
+    
+        self._db.delete_doc(self._id)
+        
+        # reinit document
+        del self._doc['_id']
+        del self._doc['_rev']
     
 class AttachmentMixin(object):
     """
